---
title: pymor
listing:
  fields: [title, description]
  type: table
  sort-ui: false
  filter-ui: false
---

This section contains API details for the [pyMOR](https://pymor.org/) extensions implemented for pyLGS.
